JsDoc Reference - links.Slider

Class Index | File Index

## Classes

- _global_
- links.Filter
- links.Graph3d
- links.Graph3d.Camera
- links.Slider

# Class links.Slider

Defined in: graph3d.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| links.Slider(container, options)

Method Summary
Method Attributes | Method Name and Description
--- | ---
| get() retrieve the currently selected value
| getIndex() retrieve the index of the currently selected vaue
| getPlayInterval(interval) Retrieve the current play interval
| indexToLeft(index)
| leftToIndex(left)
| next() Select the next index
| onChange() Execute the onchange callback function
| onmousemove(event)
| onmouseup(event)
| play() Start playing
| playNext() Select the next index
| prev() Select the previous index
| redraw() redraw the slider on the correct place
| setIndex(index) Select a value by its index
| setOnChangeCallback(callback) Set a callback function which will be triggered when the value of the slider bar has changed.
| setPlayInterval(interval) Set the interval for playing the list
| setPlayLoop(doLoop) Set looping on or off
| setValues(values) Set the list with values for the slider
| stop() Stop playing
| togglePlay() Toggle start or stop playing

Class Detail
links.Slider(container, options)

Parameters:
{Element} container
  The element where the slider will be created
{Object} options
  Available options: {boolean} visible If true (default) the slider is visible.

Method Detail
{*} get()
retrieve the currently selected value

Returns:
  {*} value

{number} getIndex()
retrieve the index of the currently selected vaue

Returns:
  {number} index

{number} getPlayInterval(interval)
Retrieve the current play interval

Parameters:
interval

Returns:
  {number} interval The interval in milliseconds

indexToLeft(index)

Parameters:
index

leftToIndex(left)

Parameters:
left

next()
Select the next index

onChange()
Execute the onchange callback function

onmousemove(event)

Parameters:
event

onmouseup(event)

Parameters:
event

play()
Start playing

playNext()
Select the next index

prev()
Select the previous index

redraw()
redraw the slider on the correct place

setIndex(index)
Select a value by its index

Parameters:
{number} index

setOnChangeCallback(callback)
Set a callback function which will be triggered when the value of the slider bar has changed.

Parameters:
callback

setPlayInterval(interval)
Set the interval for playing the list

Parameters:
{number} interval
  The interval in milliseconds

setPlayLoop(doLoop)
Set looping on or off

Parameters:
doLoop

setValues(values)
Set the list with values for the slider

Parameters:
{Array} values
  A javascript array with values (any type)

stop()
Stop playing

togglePlay()
Toggle start or stop playing

Documentation generated by JsDoc Toolkit 2.3.2 on Wed Oct 24 2012 10:03:15 GMT+0200 (CEST)